@@ -184,7 +184,7 @@ class Py3status:
             self.active = 0
 
         # reset the cycle time
-        self._cycle_time = time.perf_counter() + self.cycle
+        self._cycle_time = time.time() + self.cycle
 
     def _get_timezone(self, tz):
         """
@@ -217,7 +217,7 @@ class Py3status:
     def _change_active(self, diff):
         self.active = (self.active + diff) % len(self.format)
         # reset the cycle time
-        self._cycle_time = time.perf_counter() + self.cycle
+        self._cycle_time = time.time() + self.cycle
         # save the active format
         timezone = self.format[self.active]
         self.py3.storage_set("timezone", timezone)
@@ -241,9 +241,9 @@ class Py3status:
     def clock(self):
 
         # cycling
-        if self.cycle and time.perf_counter() >= self._cycle_time:
+        if self.cycle and time.time() >= self._cycle_time:
             self._change_active(1)
-            self._cycle_time = time.perf_counter() + self.cycle
+            self._cycle_time = time.time() + self.cycle
 
         # update our times
         times = {}
