@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Control screen rotation.
 
@@ -34,7 +33,7 @@ Color options:
     color_degraded: Screen is disconnected
     color_good: Displayed rotation is active
 
-@author Maxim Baz (https://github.com/maximbaz), lasers
+@author Maxim Baz (https://github.com/maximbaz)
 @license BSD
 
 SAMPLE OUTPUT
@@ -79,7 +78,7 @@ class Py3status:
     def _get_current_rotation_icon(self, all_outputs):
         data = self.py3.command_output(["xrandr"]).splitlines()
         output = self.screen or all_outputs[0]
-        output_line = "".join([x for x in data if x.startswith(output)])
+        output_line = "".join(x for x in data if x.startswith(output))
 
         for x in output_line.split():
             if "normal" in x or "inverted" in x:
@@ -95,7 +94,7 @@ class Py3status:
         cmd = "xrandr"
         outputs = [self.screen] if self.screen else self._get_active_outputs()
         for output in outputs:
-            cmd += " --output %s --rotate %s" % (output, rotation)
+            cmd += f" --output {output} --rotate {rotation}"
         self.py3.command_run(cmd)
 
     def _switch_selection(self):
