@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This file is used for the generation of screenshots for py3status
 documentation.
@@ -11,13 +10,13 @@ outside of pythons standard library there are the following requirements:
 PIL may work if installed but is not supported.
 """
 
-from __future__ import division
 
 import ast
 import os
 import re
 
 from hashlib import md5
+from pathlib import Path
 
 from PIL import Image, ImageFont, ImageDraw
 from fontTools.ttLib import TTFont
@@ -87,7 +86,7 @@ def get_color_for_name(module_name):
         )
         * 3
     )[5 ** int(hue) // 3 % 3 :: int(hue) % 2 + 1][:3]
-    return "#" + "%02x" * 3 % (int(r), int(g), int(b))
+    return f"#{int(r):02x}{int(g):02x}{int(b):02x}"
 
 
 def contains_bad_glyph(glyph_data, data):
@@ -106,16 +105,11 @@ def contains_bad_glyph(glyph_data, data):
 
     for part in data:
         text = part.get("full_text", "")
-        try:
-            # for python 2
-            text = text.decode("utf8")
-        except AttributeError:
-            pass
 
         for char in text:
             if not check_glyph(ord(char)):
                 # we have not found a character in the font
-                print(u"%s (%s) missing" % (char, ord(char)))
+                print("{} ({}) missing".format(char, ord(char)))
                 return True
     return False
 
@@ -189,8 +183,8 @@ def create_screenshot(name, data, path, font, is_module):
             )
             x += SEP_PADDING_LEFT
 
-    img.save(os.path.join(path, "%s.png" % name))
-    print(" %s.png" % name)
+    img.save(path / f"{name}.png")
+    print(f" {name}.png")
 
 
 def parse_sample_data(sample_data, module_name):
@@ -200,7 +194,7 @@ def parse_sample_data(sample_data, module_name):
     """
     samples = {}
     for index, chunk in enumerate(sample_data.split("\n\n")):
-        chunk = "{}-{}-{}".format(module_name, index, chunk)
+        chunk = f"{module_name}-{index}-{chunk}"
         name, sample = re.split("-?\n", chunk, 1)
         try:
             samples[name] = ast.literal_eval(sample)
@@ -215,12 +209,10 @@ def get_samples():
     return a dict {screenshot_name: sample_output}
     """
     samples = {}
-    module_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "modules")
-    for file in sorted(os.listdir(module_dir)):
-        if file.endswith(".py") and file != "__init__.py":
-            #  remove .py
-            module_name = file[:-3]
-            with open(os.path.join(module_dir, file), "r") as f:
+    module_dir = Path(__file__).resolve().parent / "modules"
+    for file in sorted(module_dir.iterdir()):
+        if file.suffix == ".py" and file.name != "__init__.py":
+            with file.open() as f:
                 try:
                     module = ast.parse(f.read())
                 except SyntaxError:
@@ -232,7 +224,7 @@ def get_samples():
                 if len(parts) == 1:
                     continue
                 sample_data = parts[1]
-                samples.update(parse_sample_data(sample_data, module_name))
+                samples.update(parse_sample_data(sample_data, file.stem))
     return samples
 
 
@@ -244,7 +236,7 @@ def process(name, path, data, module=True):
     """
     # create dir if not exists
     try:
-        os.makedirs(path)
+        path.mkdir(parents=True, exist_ok=True)
     except OSError:
         pass
 
@@ -259,7 +251,7 @@ def process(name, path, data, module=True):
         data = [data]
 
     if contains_bad_glyph(glyph_data, data):
-        print("** %s has characters not in %s **" % (name, font.getname()[0]))
+        print("** {} has characters not in {} **".format(name, font.getname()[0]))
     else:
         create_screenshot(name, data, path, font=font, is_module=module)
 
@@ -271,12 +263,9 @@ def create_screenshots(quiet=False):
     are created.
     """
     if os.environ.get("READTHEDOCS") == "True":
-        path = "../doc/screenshots"
+        path = Path("../doc/screenshots")
     else:
-        path = os.path.join(
-            os.path.dirname(os.path.dirname(os.path.abspath(__file__))),
-            "doc/screenshots",
-        )
+        path = Path(__file__).resolve().parent / "doc" / "screenshots"
 
     print("Creating screenshots...")
     samples = get_samples()
